@@ -1,21 +1,13 @@
 package Langertha::Engine::OpenAI;
 # ABSTRACT: OpenAI API
-our $VERSION = '0.201';
+our $VERSION = '0.202';
 use Moose;
 use Carp qw( croak );
 
+extends 'Langertha::Engine::OpenAIBase';
+
 with 'Langertha::Role::'.$_ for (qw(
-  JSON
-  HTTP
-  OpenAICompatible
-  OpenAPI
-  Models
-  Temperature
-  ResponseSize
   ResponseFormat
-  SystemPrompt
-  Streaming
-  Chat
   Embedding
   Transcription
 ));
@@ -29,6 +21,11 @@ has compatibility_for_engine => (
 );
 
 
+has '+url' => (
+  lazy => 1,
+  default => sub { 'https://api.openai.com/v1' },
+);
+
 sub _build_api_key {
   my ( $self ) = @_;
   return $ENV{LANGERTHA_OPENAI_API_KEY}
@@ -54,7 +51,7 @@ Langertha::Engine::OpenAI - OpenAI API
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -112,6 +109,8 @@ endpoint.
 
 =over
 
+=item * L<https://status.openai.com/> - OpenAI service status
+
 =item * L<https://platform.openai.com/docs> - Official OpenAI documentation
 
 =item * L<Langertha::Role::OpenAICompatible> - OpenAI API format role composed by this engine
