@@ -1,21 +1,10 @@
 package Langertha::Engine::Perplexity;
 # ABSTRACT: Perplexity Sonar API
-our $VERSION = '0.201';
+our $VERSION = '0.202';
 use Moose;
 use Carp qw( croak );
 
-with 'Langertha::Role::'.$_ for (qw(
-  JSON
-  HTTP
-  OpenAICompatible
-  OpenAPI
-  Models
-  Temperature
-  ResponseSize
-  SystemPrompt
-  Streaming
-  Chat
-));
+extends 'Langertha::Engine::OpenAIBase';
 
 
 sub _build_supported_operations {[qw(
@@ -26,7 +15,6 @@ has '+url' => (
   lazy => 1,
   default => sub { 'https://api.perplexity.ai' },
 );
-around has_url => sub { 1 };
 
 sub _build_api_key {
   my ( $self ) = @_;
@@ -53,7 +41,7 @@ Langertha::Engine::Perplexity - Perplexity Sonar API
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -98,6 +86,8 @@ B<THIS API IS WORK IN PROGRESS>
 
 =over
 
+=item * L<https://status.perplexity.com/> - Perplexity service status
+
 =item * L<https://docs.perplexity.ai/> - Official Perplexity API documentation
 
 =item * L<Langertha::Role::OpenAICompatible> - OpenAI API format role
