@@ -1,6 +1,6 @@
 package Langertha::Role::OpenAICompatible;
 # ABSTRACT: Role for OpenAI-compatible API format
-our $VERSION = '0.201';
+our $VERSION = '0.202';
 use Moose::Role;
 use File::ShareDir::ProjectDistDir qw( :all );
 use Carp qw( croak );
@@ -11,11 +11,13 @@ has api_key => (
   is => 'ro',
   lazy_build => 1,
 );
+sub _build_api_key { undef }
 
 
 sub update_request {
   my ( $self, $request ) = @_;
-  $request->header('Authorization', 'Bearer '.$self->api_key);
+  my $key = $self->api_key;
+  $request->header('Authorization', 'Bearer '.$key) if defined $key;
 }
 
 
@@ -78,7 +80,7 @@ sub embedding_operation_id { 'createEmbedding' }
 sub embedding_request {
   my ( $self, $input, %extra ) = @_;
   return $self->generate_request( $self->embedding_operation_id, sub { $self->embedding_response(shift) },
-    model => $self->embedding_model,
+    defined $self->embedding_model ? ( model => $self->embedding_model ) : (),
     input => $input,
     %extra,
   );
@@ -101,7 +103,7 @@ sub chat_operation_id { 'createChatCompletion' }
 sub chat_request {
   my ( $self, $messages, %extra ) = @_;
   return $self->generate_request( $self->chat_operation_id, sub { $self->chat_response(shift) },
-    model => $self->chat_model,
+    defined $self->chat_model ? ( model => $self->chat_model ) : (),
     messages => $messages,
     $self->get_response_size ? ( max_tokens => $self->get_response_size ) : (),
     ($self->can('has_response_format') && $self->has_response_format) ? ( response_format => $self->response_format ) : (),
@@ -160,7 +162,7 @@ sub stream_format { 'sse' }
 sub chat_stream_request {
   my ( $self, $messages, %extra ) = @_;
   return $self->generate_request( $self->chat_operation_id, sub {},
-    model => $self->chat_model,
+    defined $self->chat_model ? ( model => $self->chat_model ) : (),
     messages => $messages,
     $self->get_response_size ? ( max_tokens => $self->get_response_size ) : (),
     ($self->can('has_response_format') && $self->has_response_format) ? ( response_format => $self->response_format ) : (),
@@ -267,7 +269,7 @@ Langertha::Role::OpenAICompatible - Role for OpenAI-compatible API format
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -300,14 +302,6 @@ The role provides default implementations for all OpenAI-format operations.
 Engines can override individual methods to customize behavior (e.g.,
 different operation IDs for Mistral, or disabling unsupported features).
 
-B<Engines composing this role must provide:>
-
-=over 4
-
-=item * C<_build_api_key> - Returns the API key (from env var or config)
-
-=back
-
 B<Engines should also compose these roles:>
 
 =over 4
@@ -329,15 +323,18 @@ L<Langertha::Engine::OllamaOpenAI>, L<Langertha::Engine::AKIOpenAI>.
 
 =head2 api_key
 
-The API key used for Bearer token authentication. Set via C<_build_api_key>
-in each engine (typically from an environment variable). Required.
+Optional API key for Bearer token authentication. Override
+C<_build_api_key> in engines that require authentication (typically
+from an environment variable). When C<undef>, no Authorization header
+is sent.
 
 =head2 update_request
 
     $role->update_request($http_request);
 
-Adds C<Authorization: Bearer {api_key}> header to outgoing requests.
-Called automatically before each request.
+Adds C<Authorization: Bearer {api_key}> header to outgoing requests
+when an API key is configured. Skipped when C<api_key> is C<undef>
+(e.g. for local servers like vLLM or llama.cpp).
 
 =head2 openapi_file
 
